<?php

class PayshopUpdateOrder
{
    /**
     * Update order and save metadata
     *
     * @param int $orderId
     * @param string $newOrderStatus
     * @param int $payshopChargeId
     * @param int $payshopInstrumentId
     * @param int $payshopPaymentId
     * @return void
     */
    public function execute(
        $orderId,
        $newOrderStatus,
        $payshopChargeId,
        $payshopInstrumentId,
        $payshopPaymentId = null
    )
    {
        $order = new WC_Order($orderId);

        $this->savePayhsopMetadata(
            $order,
            $payshopChargeId,
            $payshopInstrumentId,
            $payshopPaymentId
        );

        $this->updatePrestashopOrder($order, $newOrderStatus, $payshopChargeId);
    }

    /**
     * Update Payshop transaction status
     * 
     * @param WC_Order  $order
     * @param int $payshopChargeId
     * @param int $payshopInstrumentId
     * @param int $payshopPaymentId
     * @return void
     */
     private function savePayhsopMetadata(
        $order,
        $payshopChargeId,
        $payshopInstrumentId,
        $payshopPaymentId
    )
    {
        $order->update_meta_data('_payshop_charge_id', $payshopChargeId, true);
        $order->update_meta_data('_payshop_instrument_id', $payshopInstrumentId, true);

        if ($payshopPaymentId) {
            $order->update_meta_data('_payshop_payment_id', $payshopPaymentId, true);
        }
    }

    /**
     * Update Prestashop order status
     *
     * @param WC_Order $order
     * @param string $newOrderStatus
     * @return void
     */
    private function updatePrestashopOrder($order, $newOrderStatus)
    {
        $order->update_status($newOrderStatus, $this->getOrderStatusMessage($newOrderStatus));

        $this->payed($order, $newOrderStatus,);
    }

    /**
     * Update order status to payed
     *
     * @param WC_Order $order
     * @param string $newOrderStatus
     * @return void
     */
    private function payed($order, $newOrderStatus)
    {
        if ($newOrderStatus !== 'processing') {
            return;
        }

        $order->payment_complete();
        wc_reduce_stock_levels($order);
        
        global $woocommerce;
        $woocommerce->cart->empty_cart();
    }

    /**
     * Get order status message
     *
     * @param string $newOrderStatus
     * @return string
     */
    private function getOrderStatusMessage($newOrderStatus) {
        switch ($newOrderStatus) {
            case 'completed':
                return __('Payment completed', 'payshop');
            case 'processing':
                return __('Payment approved', 'payshop');
            case 'on-hold':
                return __('Payment on hold', 'payshop');
            case 'cancelled':
                return __('Payment cancelled', 'payshop');
            case 'failed':
                return __('Payment failed', 'payshop');
            default:
                return __('Payment status updated', 'payshop');
        }
    }
}