<?php

class PayshopCredentialsAlert extends PayshopAbstractAlert
{
    /**
     * Check if credentials are set
     * 
     * @return void
     */
    public function execute()
    {
        $this->checkAccountId();

        $this->checkProdutionCredencials();

        $this->checkSandboxCredencials();
    }

    /**
     * Check if account id is set
     * 
     * @return void
     */
    private function checkAccountId()
    {
        if (!get_option('payshop_account_id')) {
            $type    = 'error';
            $message = __('Payshop Error: Fill Account ID on Payshop settings.', 'payshop');

            $this->show($type, $message);
        }
    }

    /**
     * Check if production credentials are set
     * 
     * @return void
     */
    private function checkProdutionCredencials()
    {
        if (get_option('payshop_environment') == 'sandbox') {
            return;
        }

        if (!get_option('payshop_public_key') || !get_option('payshop_private_key')) {
            $type    = 'error';
            $message = __('Payshop Error: Check prodution credentials on payshop settings.', 'payshop');

            $this->show($type, $message);
        }
    }

    /**
     * Check if sandbox credentials are set
     * 
     * @return void
     */
    private function checkSandboxCredencials()
    {
        if (get_option('payshop_environment') == 'production') {
            return;
        }

        if (!get_option('payshop_sandbox_public_key') || !get_option('payshop_sandbox_private_key')) {
            $type    = 'error';
            $message = __('Payshop Error: Check Sandbox credentials on payshop settings.', 'payshop');

            $this->show($type, $message);
        }
    }
}