<?php

class PayshopCredentialsSettings
{
    /**
     * Define payshop credentials settings
     * 
     * @return void
     */
    public function execute()
    {
        add_filter('woocommerce_settings_tabs_array', [$this, 'addSettingsTab'], 50);
        add_action('woocommerce_settings_tabs_payshop', [$this, 'settingsTab']);
        add_action('woocommerce_update_options_payshop', [$this, 'updateSettings']);
    }
    
    /**
     * Add payshop settings tab
     * 
     * @param array $settingsTabs
     * @return array
     */
    public function addSettingsTab($settingsTabs)
    {
        $settingsTabs['payshop'] = __('Payshop', 'payshop');

        return $settingsTabs;
    }

    /**
     * Define fields in Settings tab
     * 
     * @return void
     */
    public function settingsTab()
    {
        woocommerce_admin_fields($this->getSettings());
    }

    /**
     * Save settings fields
     * 
     * @return array
     */
    public function updateSettings()
    {
        woocommerce_update_options($this->getSettings());
    }

    /**
     * Define settings fields
     * 
     * @return array
     */
    private function getSettings()
    {
        return $this->generalSettings() + 
               $this->productionApiSettings() +
               $this->sandboxApiSettings();
    }

    /**
     * Define general settings fields
     * 
     * @return array
     */
    private function generalSettings()
    {
        return [
            'section_general_title' => [
                'name' => __('Payshop Settings', 'payshop'),
                'type' => 'title',
                'desc' => '',
                'id' => 'section_general_title'
            ],
            'payshop_environment' => [
                'name' => __('Environment', 'payshop'),
                'type' => 'select',
                'desc' => __('Select the environment you want to use', 'payshop'),
                'id' => 'payshop_environment',
                'options' => [
                    'sandbox' => __('Sandbox', 'payshop'),
                    'production' => __('Production', 'payshop')
                ]
            ],
            'section_general_end' => [
                'type' => 'sectionend',
                'id' => 'section_general_end'
            ]
        ];
    }

    /**
     * Define production API settings fields
     * 
     * @return array
     */
    private function productionApiSettings()
    {
        return [
            'section_production_title' => [
                'name' => __('Payshop Prodution Credentials', 'payshop'),
                'type' => 'title',
                'desc' => '',
                'id' => 'section_production_title'
            ],
            'payshop_account_id' => [
                'name' => __('Account ID', 'payshop'),
                'type' => 'text',
                'custom_attributes' => ['required' => 'required'],
                'desc' => __('Enter your Payshop account ID', 'payshop'),
                'id' => 'payshop_account_id'
            ],
            'payshop_public_key' => [
                'name' => __('Public Key', 'payshop'),
                'type' => 'text',
                'desc' => __('Enter your Payshop public Key', 'payshop'),
                'id' => 'payshop_public_key'
            ],
            'payshop_private_key' => [
                'name' => __('Private Key', 'payshop'),
                'type' => 'text',
                'desc' => __('Enter your Payshop private Key', 'payshop'),
                'id' => 'payshop_private_key'
            ],
            'section_production_end' => [
                'type' => 'sectionend',
                'id' => 'section_production_end'
            ]
        ];
    }

    /**
     * Define sandbox API settings fields
     * 
     * @return array
     */
    private function sandboxApiSettings()
    {
        return [
            'section_sandbox_title' => [
                'name' => __('Payshop Sandbox (test) Credentials', 'payshop'),
                'type' => 'title',
                'desc' => '',
                'id' => 'section_sandbox_title'
            ],
            'payshop_sandbox_account_id' => [
                'name' => __('Account ID', 'payshop'),
                'type' => 'text',
                'custom_attributes' => ['required' => 'required'],
                'desc' => __('Enter your Payshop account ID', 'payshop'),
                'id' => 'payshop_sandbox_account_id'
            ],
            'payshop_sandbox_public_key' => [
                'name' => __('Public Key', 'payshop'),
                'type' => 'text',
                'desc' => __('Enter your Payshop public Key', 'payshop'),
                'id' => 'payshop_sandbox_public_key'
            ],
            'payshop_sandbox_private_key' => [
                'name' => __('Private Key', 'payshop'),
                'type' => 'text',
                'desc' => __('Enter your Payshop private Key', 'payshop'),
                'id' => 'payshop_sandbox_private_key'
            ],
            'section_sandbox_end' => [
                'type' => 'sectionend',
                'id' => 'section_sandbox_end'
            ]
        ];
    }
}

