<?php

require_once 'PayshopClient.php';

class PayshopClientFactory
{
    public function __construct()
    {
    }

    static $payshopClient = null;

    /**
     * Instanciete the class
     *
     * @return PayshopClient
     */
    public static function getInstance()
    {
        if (null === self::$payshopClient) {
            try {
                self::$payshopClient = new PayshopClient(
                    self::getPublicKey(),
                    self::getSecretKey(),
                    self::getAccountId(),
                    self::isProduction()
                );
                
            } catch (\Exception $e) {
                $message = 'API ' . $e->getMessage();
                
                PayshopLog::generate($message, PayshopLog::LOG_SEVERITY_ERROR);
            }
        }

        return self::$payshopClient;
    }

    /**
     * Check if the module is in production mode
     *
     * @return boolean
     */
    public static function isProduction()
    {
        return get_option('payshop_environment') == 'production';
    }

    /**
     * Get public key based on the environment
     *
     * @return string
     */
    public static function getPublicKey()
    {
        if (self::isProduction() == true) {
            return get_option('payshop_public_key');
        }

        return get_option('payshop_sandbox_public_key');
    }

    /**
     * Get secret key based on the environment
     *
     * @return string
     */
    private static function getSecretKey()
    {
        if (self::isProduction() == true) {
            return get_option('payshop_private_key');
        }

        return get_option('payshop_sandbox_private_key');
    }

    /**
     * Get account ID based on the environment
     *
     * @return string
     */
    private static function getAccountId()
    {
        if (self::isProduction() == true) {
            return get_option('payshop_account_id');
        }

        return get_option('payshop_sandbox_account_id');
    }
}